@@ -30,13 +30,13 @@ for (ii in items) {
       deriv[,ox] <- got$D
     }
     if (ii$factors == 1) {
-      expect_equal(analytic$gradient, c(deriv[1,]), 1e-6)
-      expect_equal(analytic$hessian, c(deriv[2,]), 1e-3)
+      expect_equal(analytic$gradient, c(deriv[1,]), tolerance=1e-6)
+      expect_equal(analytic$hessian, c(deriv[2,]), tolerance=1e-3)
     } else {
       expect_equal(analytic$gradient,
-                   c(dir %*% deriv[c(1:ii$factors),]), 1e-6)
+                   c(dir %*% deriv[c(1:ii$factors),]), tolerance=1e-6)
       expect_equal(analytic$hessian,
-                   c(dir %*% deriv[c(ii$factors+triSize(1:ii$factors)),]), 1e-3)
+                   c(dir %*% deriv[c(ii$factors+triSize(1:ii$factors)),]), tolerance=1e-3)
     }
   })
 }
